"""Top-level package for geocube."""

__author__ = """Geocube Contributors"""
__email__ = "alansnow21@gmail.com"

from geocube._show_versions import show_versions  # noqa
from geocube._version import __version__  # noqa
